@@ -60,10 +60,39 @@ effect.
 
 Please add to this imaginary world and help make it real, either by
 telling me what Perl looks like in your imagination
-(F<http://github.com/schwern/perl5i/issues>) or make a fork (forking on
+(F<http://github.com/evalEmpire/perl5i/issues>) or make a fork (forking on
 github is like a branch you control) and implement it yourself.
 
 
+=head1 Rationale
+
+Changing perl 5 core is a slow and difficult process.
+Perl 5 aims to be compatible with ancient versions which means it is
+mostly stuck with design, decisions and defaults made way back in
+the 90's.
+
+There are modules in CPAN to solve or ease many of those issues but
+many people don't know about them or don't know which ones to use.
+
+Documentation and books are updated slowly and don't usually keep up;
+this information becomes some sort of community knowledge, invisible
+from the wider audience.
+
+Even if you know a solution, having to decide everytime which
+module to use and enable it individually might be enough for you to
+give up and just do things the old way.
+
+Perl5i brings all this community knowledge in a coherent way, in
+something like 'the best of CPAN', enabled with a single command.
+
+You don't need to know all it does nor how it does it, you just
+C<use perl5i::2> on your code and you automatically get a modern
+environment, with perl defaults, problems and inconsistencies fixed.
+
+You can refer beginers to perl5i and they can benefit from it without
+needing to become a perl guru first.
+
+
 =head1 Using perl5i
 
 Because perl5i I<plans> to be incompatible in the future, you do not
@@ -204,7 +233,7 @@ capabilities.  Planned expansions include:
   Parameter traits
   Traditional prototypes
 
-See L<http://github.com/schwern/perl5i/issues/labels/syntax#issue/19> for
+See L<http://github.com/evalEmpire/perl5i/issues/labels/syntax#issue/19> for
 more details about future expansions.
 
 The equivalencies above should only be taken for illustrative
@@ -306,6 +335,16 @@ All of the methods provided by L<autobox::Core> are available from perl5i.
 
 in addition, perl5i adds some methods of its own.
 
+=head3 path
+
+    my $object = $path->path;
+
+Creates a L<Path::Tiny> $object for the given file or directory $path.
+
+    my $path = "/foo/bar/baz.txt"->path;
+    my $content = $path->slurp;
+
+
 =head3 center
 
     my $centered_string = $string->center($length);
@@ -1166,9 +1205,9 @@ Some parts are not lexical.  Some parts are package scoped.
 If you're going to use two versions of perl5i together, we do not
 currently recommend having them in the same package.
 
-See L<http://github.com/schwern/perl5i/issues/labels/bug> for a complete list.
+See L<http://github.com/evalEmpire/perl5i/issues/labels/bug> for a complete list.
 
-Please report bugs at L<http://github.com/schwern/perl5i/issues/>.
+Please report bugs at L<http://github.com/evalEmpire/perl5i/issues/>.
 
 
 =head1 VERSIONING
@@ -1218,10 +1257,10 @@ See L<http://dev.perl.org/licenses/artistic.html>
 
 =head1 SEE ALSO
 
-Repository:   L<http://github.com/schwern/perl5i/tree/master>
-Issues/Bugs:  L<http://github.com/schwern/perl5i/issues>
+Repository:   L<http://github.com/evalEmpire/perl5i/>
+Issues/Bugs:  L<http://github.com/evalEmpire/perl5i/issues>
 IRC:          L<irc://irc.perl.org> on the #perl5i channel
-Wiki:         L<http://github.com/schwern/perl5i/wiki>
+Wiki:         L<http://github.com/evalEmpire/perl5i/wiki>
 Twitter:      L<http://twitter.com/perl5i>
 
 Frequently Asked Questions about perl5i: L<perl5ifaq>
